==> zio-aws-redshift_2.13-5.17.128.1-sources.jar: zio/aws/redshift/model/RecurringCharge.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RecurringCharge(
    recurringChargeAmount: Option[Double] = None,
    recurringChargeFrequency: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.RecurringCharge = {
    import RecurringCharge.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.RecurringCharge
      .builder()
      .optionallyWith(
        recurringChargeAmount.map(value => value: java.lang.Double)
      )(_.recurringChargeAmount)
      .optionallyWith(
        recurringChargeFrequency.map(value => value: java.lang.String)
      )(_.recurringChargeFrequency)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.RecurringCharge.ReadOnly =
    zio.aws.redshift.model.RecurringCharge.wrap(buildAwsValue())
}
object RecurringCharge {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.RecurringCharge
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.RecurringCharge =
      zio.aws.redshift.model.RecurringCharge(
        recurringChargeAmount.map(value => value),
        recurringChargeFrequency.map(value => value)
      )
    def recurringChargeAmount: Option[Double]
    def recurringChargeFrequency: Option[String]
    def getRecurringChargeAmount: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("recurringChargeAmount", recurringChargeAmount)
    def getRecurringChargeFrequency: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("recurringChargeFrequency", recurringChargeFrequency)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.RecurringCharge
  ) extends zio.aws.redshift.model.RecurringCharge.ReadOnly {
    override val recurringChargeAmount: Option[Double] =
      scala.Option(impl.recurringChargeAmount()).map(value => value: Double)
    override val recurringChargeFrequency: Option[String] =
      scala.Option(impl.recurringChargeFrequency()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.RecurringCharge
  ): zio.aws.redshift.model.RecurringCharge.ReadOnly = new Wrapper(impl)
}

==> zio-aws-redshift_2.13-6.20.78.1-sources.jar: zio/aws/redshift/model/RecurringCharge.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RecurringCharge(
    recurringChargeAmount: Optional[Double] = Optional.Absent,
    recurringChargeFrequency: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.RecurringCharge = {
    import RecurringCharge.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.RecurringCharge
      .builder()
      .optionallyWith(
        recurringChargeAmount.map(value => value: java.lang.Double)
      )(_.recurringChargeAmount)
      .optionallyWith(
        recurringChargeFrequency.map(value => value: java.lang.String)
      )(_.recurringChargeFrequency)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.RecurringCharge.ReadOnly =
    zio.aws.redshift.model.RecurringCharge.wrap(buildAwsValue())
}
object RecurringCharge {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.RecurringCharge
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.RecurringCharge =
      zio.aws.redshift.model.RecurringCharge(
        recurringChargeAmount.map(value => value),
        recurringChargeFrequency.map(value => value)
      )
    def recurringChargeAmount: Optional[Double]
    def recurringChargeFrequency: Optional[String]
    def getRecurringChargeAmount: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("recurringChargeAmount", recurringChargeAmount)
    def getRecurringChargeFrequency: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("recurringChargeFrequency", recurringChargeFrequency)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.RecurringCharge
  ) extends zio.aws.redshift.model.RecurringCharge.ReadOnly {
    override val recurringChargeAmount: Optional[Double] = zio.aws.core.internal
      .optionalFromNullable(impl.recurringChargeAmount())
      .map(value => value: Double)
    override val recurringChargeFrequency: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recurringChargeFrequency())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.RecurringCharge
  ): zio.aws.redshift.model.RecurringCharge.ReadOnly = new Wrapper(impl)
}
